PALM-meteo: palmmeteo_stdplugins.aladin Namespace Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Functions | Variables
palmmeteo_stdplugins.aladin Namespace Reference

## Classes
class | AladinCoordTransform
class | AladinPlugin
class | AladinRadPlugin
class | BilinearRegridder

## Functions
| variable2parameter ()
| findnearest (xlon, xlat, point)
| transform_from_grib (filename, fileout, cfg, **kwargs)
| log_dstat_on (desc, delta)
| log_dstat_off (desc, delta)
| palm_alad_gw (f, lon, lat, levels, tidx=0)
| minterp (interp_heights, data_heights, u, v)
| get_wrf_dims (f, lat, lon, xlat, xlong)
| calcgw_wrf (f, lat, lon, levels, tidx=0)
| aladin_t (f, it)
| description_key ()

## Variables
| barom_pres = PalmPhysics.barom_lapse0_pres
| barom_gp = PalmPhysics.barom_lapse0_gp
| g = PalmPhysics.g
| ax_ = np.newaxis
int | gw_gfs_margin_deg = 5.
int | gw_wrf_margin_km = 10.
int | gw_alpha = 1.

## Function Documentation

## ◆ aladin_t()

palmmeteo_stdplugins.aladin.aladin_t | ( |  | f,
|  |  | it
| ) |  |

## ◆ calcgw_wrf()

palmmeteo_stdplugins.aladin.calcgw_wrf | ( |  | f,
|  |  | lat,
|  |  | lon,
|  |  | levels,
|  |  | tidx = `0`
| ) |  |

## ◆ description_key()

palmmeteo_stdplugins.aladin.description_key | ( |  | ) |

## ◆ findnearest()

palmmeteo_stdplugins.aladin.findnearest | ( |  | xlon,
|  |  | xlat,
|  |  | point
| ) |  |

## ◆ get_wrf_dims()

palmmeteo_stdplugins.aladin.get_wrf_dims | ( |  | f,
|  |  | lat,
|  |  | lon,
|  |  | xlat,
|  |  | xlong
| ) |  |

    A crude method, yet satisfactory for approximate WRF surroundings

## ◆ log_dstat_off()

palmmeteo_stdplugins.aladin.log_dstat_off | ( |  | desc,
|  |  | delta
| ) |  |

    Do nothing (log disabled)

## ◆ log_dstat_on()

palmmeteo_stdplugins.aladin.log_dstat_on | ( |  | desc,
|  |  | delta
| ) |  |

    Calculate and log delta statistics if enabled.

## ◆ minterp()

palmmeteo_stdplugins.aladin.minterp | ( |  | interp_heights,
|  |  | data_heights,
|  |  | u,
|  |  | v
| ) |  |

    Interpolate wind using power law for agl levels

## ◆ palm_alad_gw()

palmmeteo_stdplugins.aladin.palm_alad_gw | ( |  | f,
|  |  | lon,
|  |  | lat,
|  |  | levels,
|  |  | tidx = `0`
| ) |  |

    Calculate geostrophic wind from WRF using metpy

## ◆ transform_from_grib()

palmmeteo_stdplugins.aladin.transform_from_grib | ( |  | filename,
|  |  | fileout,
|  |  | cfg,
|  | ** | kwargs
| ) |  |

## ◆ variable2parameter()

palmmeteo_stdplugins.aladin.variable2parameter | ( |  | ) |

## Variable Documentation

## ◆ ax_

palmmeteo_stdplugins.aladin.ax_ = np.newaxis

## ◆ barom_gp

palmmeteo_stdplugins.aladin.barom_gp = PalmPhysics.barom_lapse0_gp

## ◆ barom_pres

palmmeteo_stdplugins.aladin.barom_pres = PalmPhysics.barom_lapse0_pres

## ◆ g

palmmeteo_stdplugins.aladin.g = PalmPhysics.g

## ◆ gw_alpha

int palmmeteo_stdplugins.aladin.gw_alpha = 1.

## ◆ gw_gfs_margin_deg

int palmmeteo_stdplugins.aladin.gw_gfs_margin_deg = 5.

## ◆ gw_wrf_margin_km

int palmmeteo_stdplugins.aladin.gw_wrf_margin_km = 10.